<?php
/**
 * Plugin Name:       WPForms AWeber
 * Plugin URI:        https://wpforms.com
 * Description:       AWeber integration with WPForms.
 * Requires at least: 5.2
 * Requires PHP:      5.6
 * Author:            WPForms
 * Author URI:        https://wpforms.com
 * Version:           1.3.1
 * Text Domain:       wpforms-aweber
 * Domain Path:       languages
 *
 * WPForms is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * any later version.
 *
 * WPForms is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with WPForms. If not, see <https://www.gnu.org/licenses/>.
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Plugin version.
 *
 * @since 1.0.0
 */
define( 'WPFORMS_AWEBER_VERSION', '1.3.1' );

/**
 * Load addon if requirements passed.
 *
 * @since 1.0.0
 */
function wpforms_aweber() {

	// WPForms Pro is required.
	if (
		! function_exists( 'wpforms' ) ||
		! function_exists( 'wpforms_get_license_type' ) ||
		! wpforms()->pro ||
		! in_array( wpforms_get_license_type(), [ 'plus', 'pro', 'elite', 'agency', 'ultimate' ], true )
	) {
		return;
	}

	// PHP cURL extension is required.
	if ( ! function_exists( 'curl_version' ) ) {
		add_action( 'admin_notices', 'wpforms_aweber_fail_curl' );
		add_action( 'admin_init', 'wpforms_aweber_deactivate' );

		return;
	}

	require_once plugin_dir_path( __FILE__ ) . 'class-aweber.php';
}

add_action( 'wpforms_loaded', 'wpforms_aweber' );

/**
 * Deactivate plugin.
 *
 * @since 1.3.1
 */
function wpforms_aweber_deactivate() {

	deactivate_plugins( plugin_basename( __FILE__ ) );
}

/**
 * Admin notice for PHP extension.
 *
 * @since 1.3.1
 */
function wpforms_aweber_fail_curl() {

	echo '<div class="notice notice-error"><p>';
	esc_html_e( 'The WPForms AWeber plugin has been deactivated. Your server is missing a cURL extension for PHP and therefore is not compatible with the AWeber addon. Please contact your hosting support to enable a cURL extension for PHP.', 'wpforms-aweber' );
	echo '</p></div>';

	// phpcs:disable WordPress.Security.NonceVerification.Recommended
	if ( isset( $_GET['activate'] ) ) {
		unset( $_GET['activate'] );
	}
	// phpcs:enable WordPress.Security.NonceVerification.Recommended
}

/**
 * Load the plugin updater.
 *
 * @since 1.0.0
 *
 * @param string $key WPForms license key.
 */
function wpforms_aweber_updater( $key ) {

	new WPForms_Updater(
		[
			'plugin_name' => 'WPForms AWeber',
			'plugin_slug' => 'wpforms-aweber',
			'plugin_path' => plugin_basename( __FILE__ ),
			'plugin_url'  => trailingslashit( plugin_dir_url( __FILE__ ) ),
			'remote_url'  => WPFORMS_UPDATER_API,
			'version'     => WPFORMS_AWEBER_VERSION,
			'key'         => $key,
		]
	);
}

add_action( 'wpforms_updater', 'wpforms_aweber_updater' );
