<?php
/**
 * Plugin Name:       WPForms Sendinblue
 * Plugin URI:        https://wpforms.com
 * Description:       Sendinblue integration with WPForms.
 * Requires at least: 5.2
 * Requires PHP:      5.6
 * Author:            WPForms
 * Author URI:        https://wpforms.com
 * Version:           1.1.0
 * Text Domain:       wpforms-sendinblue
 * Domain Path:       languages
 *
 * WPForms is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * any later version.
 *
 * WPForms is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with WPForms. If not, see <https://www.gnu.org/licenses/>.
 */

use WPFormsSendinblue\Plugin;

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Plugin constants.
// phpcs:disable WPForms.Comments.PHPDocDefine.MissPHPDoc
define( 'WPFORMS_SENDINBLUE_VERSION', '1.1.0' );
define( 'WPFORMS_SENDINBLUE_FILE', __FILE__ );
define( 'WPFORMS_SENDINBLUE_PATH', plugin_dir_path( WPFORMS_SENDINBLUE_FILE ) );
define( 'WPFORMS_SENDINBLUE_URL', plugin_dir_url( WPFORMS_SENDINBLUE_FILE ) );
// phpcs:enable WPForms.Comments.PHPDocDefine.MissPHPDoc

/**
 * Load the provider class.
 *
 * @since 1.0.0
 */
function wpforms_sendinblue_load() {

	// Check requirements.
	if ( ! wpforms_sendinblue_required() ) {
		return;
	}

	// Load the plugin.
	wpforms_sendinblue();
}

add_action( 'wpforms_loaded', 'wpforms_sendinblue_load' );

/**
 * Check addon requirements.
 *
 * @since 1.0.0
 */
function wpforms_sendinblue_required() {

	if ( version_compare( PHP_VERSION, '5.6', '<' ) ) {
		add_action( 'admin_init', 'wpforms_sendinblue_deactivation' );
		add_action( 'admin_notices', 'wpforms_sendinblue_fail_php_version' );

		return false;
	}

	if (
		! function_exists( 'wpforms' ) ||
		version_compare( wpforms()->version, '1.7.6', '<' )
	) {
		add_action( 'admin_init', 'wpforms_sendinblue_deactivation' );
		add_action( 'admin_notices', 'wpforms_sendinblue_fail_wpforms_version' );

		return false;
	}

	if (
		! wpforms()->is_pro() ||
		! function_exists( 'wpforms_get_license_type' ) ||
		! in_array( wpforms_get_license_type(), [ 'plus', 'pro', 'elite', 'agency', 'ultimate' ], true )
	) {
		return false;
	}

	return true;
}

/**
 * Deactivate the plugin.
 *
 * @since 1.0.0
 */
function wpforms_sendinblue_deactivation() {

	deactivate_plugins( plugin_basename( __FILE__ ) );
}

/**
 * Admin notice for a minimum PHP version.
 *
 * @since 1.0.0
 */
function wpforms_sendinblue_fail_php_version() {

	echo '<div class="notice notice-error"><p>';
	printf(
		wp_kses( /* translators: %s - WPForms.com documentation page URL. */
			__( 'The WPForms Sendinblue plugin has been deactivated. Your site is running an outdated version of PHP that is no longer supported and is not compatible with the Sendinblue addon. <a href="%s" target="_blank" rel="noopener noreferrer">Read more</a> for additional information.', 'wpforms-sendinblue' ),
			[
				'a' => [
					'href'   => [],
					'rel'    => [],
					'target' => [],
				],
			]
		),
		'https://wpforms.com/docs/supported-php-version/'
	);
	echo '</p></div>';

	// phpcs:disable WordPress.Security.NonceVerification.Recommended
	if ( isset( $_GET['activate'] ) ) {
		unset( $_GET['activate'] );
	}
	// phpcs:enable WordPress.Security.NonceVerification.Recommended
}

/**
 * Admin notice for minimum WPForms version.
 *
 * @since 1.0.0
 */
function wpforms_sendinblue_fail_wpforms_version() {

	echo '<div class="notice notice-error"><p>';
	esc_html_e( 'The WPForms Sendinblue plugin has been deactivated, because it requires WPForms v1.7.6 or later to work.', 'wpforms-sendinblue' );
	echo '</p></div>';

	// phpcs:disable WordPress.Security.NonceVerification.Recommended
	if ( isset( $_GET['activate'] ) ) {
		unset( $_GET['activate'] );
	}
	// phpcs:enable WordPress.Security.NonceVerification.Recommended
}

/**
 * Get the instance of the `\WPFormsSendinblue\Plugin` class.
 * This function is useful to quickly grabbing data used throughout the plugin.
 *
 * @since 1.0.0
 *
 * @return Plugin
 */
function wpforms_sendinblue() {

	// Load the Sendinblue addon now, as we met all the requirements.
	require_once WPFORMS_SENDINBLUE_PATH . '/vendor/autoload.php';

	return Plugin::get_instance();
}
